# simple heiiiioptgh package

## usage example

```py
from gosimplepack import circle_area
ans = circle_area(7)
print(ans)
```

> 153.93804002589985

## Other example

```py
from gosimplepack import add, subtract, divide
addn = add(5, 6)
print(addn)
```

made by [3ekodomo](https://github.com/3ekodomo).
